==> openflowplugin-extension-nicira-0.5.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/update/flow/input/updated/flow/instructions/instruction/instruction/write/actions/_case/write/actions/action/action/NxActionLearnRpcUpdateFlowUpdatedWriteActionsCase.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.update.flow.input.updated.flow.instructions.instruction.instruction.write.actions._case.write.actions.action.action;
import org.opendaylight.yang.gen.v1.urn.opendaylight.action.types.rev131112.action.Action;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionLearnGrouping;

/**
 * <p>This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * case nx-action-learn-rpc-update-flow-updated-write-actions-case {
 *     container nx-learn {
 *         leaf idle-timeout {
 *             type uint16;
 *         }
 *         leaf hard-timeout {
 *             type uint16;
 *         }
 *         leaf priority {
 *             type uint16;
 *         }
 *         leaf cookie {
 *             type uint64;
 *         }
 *         leaf flags {
 *             type uint16;
 *         }
 *         leaf table-id {
 *             type uint8;
 *         }
 *         leaf fin-idle-timeout {
 *             type uint16;
 *         }
 *         leaf fin-hard-timeout {
 *             type uint16;
 *         }
 *         list flow-mods {
 *             key     choice flow-mod-spec {
 *                 case flow-mod-add-match-from-field-case {
 *                     container flow-mod-add-match-from-field {
 *                         leaf flow-mod-num-bits {
 *                             type uint16;
 *                         }
 *                         leaf src-field {
 *                             type uint32;
 *                         }
 *                         leaf src-ofs {
 *                             type uint16;
 *                         }
 *                         leaf dst-field {
 *                             type uint32;
 *                         }
 *                         leaf dst-ofs {
 *                             type uint16;
 *                         }
 *                     }
 *                 }
 *                 case flow-mod-add-match-from-value-case {
 *                     container flow-mod-add-match-from-value {
 *                         leaf flow-mod-num-bits {
 *                             type uint16;
 *                         }
 *                         leaf value {
 *                             type uint16;
 *                         }
 *                         leaf src-field {
 *                             type uint32;
 *                         }
 *                         leaf src-ofs {
 *                             type uint16;
 *                         }
 *                     }
 *                 }
 *                 case flow-mod-copy-field-into-field-case {
 *                     container flow-mod-copy-field-into-field {
 *                         leaf flow-mod-num-bits {
 *                             type uint16;
 *                         }
 *                         leaf src-field {
 *                             type uint32;
 *                         }
 *                         leaf src-ofs {
 *                             type uint16;
 *                         }
 *                         leaf dst-field {
 *                             type uint32;
 *                         }
 *                         leaf dst-ofs {
 *                             type uint16;
 *                         }
 *                     }
 *                 }
 *                 case flow-mod-copy-value-into-field-case {
 *                     container flow-mod-copy-value-into-field {
 *                         leaf flow-mod-num-bits {
 *                             type uint16;
 *                         }
 *                         leaf value {
 *                             type uint16;
 *                         }
 *                         leaf dst-field {
 *                             type uint32;
 *                         }
 *                         leaf dst-ofs {
 *                             type uint16;
 *                         }
 *                     }
 *                 }
 *                 case flow-mod-output-to-port-case {
 *                     container flow-mod-output-to-port {
 *                         leaf flow-mod-num-bits {
 *                             type uint16;
 *                         }
 *                         leaf src-field {
 *                             type uint32;
 *                         }
 *                         leaf src-ofs {
 *                             type uint16;
 *                         }
 *                     }
 *                 }
 *             }
 *             uses flow-mod-spec;
 *         }
 *     }
 * }
 * </pre>
 * The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/update-flow/input/updated-flow/instructions/instruction/instruction/write-actions-case/write-actions/action/action/(urn:opendaylight:openflowplugin:extension:nicira:action?revision=2014-07-14)nx-action-learn-rpc-update-flow-updated-write-actions-case</i>
 *
 */
public interface NxActionLearnRpcUpdateFlowUpdatedWriteActionsCase
    extends
    DataObject,
    Augmentable<org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.update.flow.input.updated.flow.instructions.instruction.instruction.write.actions._case.write.actions.action.action.NxActionLearnRpcUpdateFlowUpdatedWriteActionsCase>,
    NxActionLearnGrouping,
    Action
{



    public static final QName QNAME = org.opendaylight.yangtools.yang.common.QName.create("urn:opendaylight:openflowplugin:extension:nicira:action",
        "2014-07-14", "nx-action-learn-rpc-update-flow-updated-write-actions-case").intern();


}

==> openflowplugin-extension-nicira-0.5.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/update/flow/input/updated/flow/instructions/instruction/instruction/write/actions/_case/write/actions/action/action/NxActionLearnRpcUpdateFlowUpdatedWriteActionsCase.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.update.flow.input.updated.flow.instructions.instruction.instruction.write.actions._case.write.actions.action.action;
import org.opendaylight.yang.gen.v1.urn.opendaylight.action.types.rev131112.action.Action;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionLearnGrouping;

/**
 * <p>This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * case nx-action-learn-rpc-update-flow-updated-write-actions-case {
 *     container nx-learn {
 *         leaf idle-timeout {
 *             type uint16;
 *         }
 *         leaf hard-timeout {
 *             type uint16;
 *         }
 *         leaf priority {
 *             type uint16;
 *         }
 *         leaf cookie {
 *             type uint64;
 *         }
 *         leaf flags {
 *             type uint16;
 *         }
 *         leaf table-id {
 *             type uint8;
 *         }
 *         leaf fin-idle-timeout {
 *             type uint16;
 *         }
 *         leaf fin-hard-timeout {
 *             type uint16;
 *         }
 *         list flow-mods {
 *             choice flow-mod-spec {
 *                 case flow-mod-add-match-from-field-case {
 *                     container flow-mod-add-match-from-field {
 *                         leaf flow-mod-num-bits {
 *                             type uint16;
 *                         }
 *                         leaf src-field {
 *                             type uint32;
 *                         }
 *                         leaf src-ofs {
 *                             type uint16;
 *                         }
 *                         leaf dst-field {
 *                             type uint32;
 *                         }
 *                         leaf dst-ofs {
 *                             type uint16;
 *                         }
 *                     }
 *                 }
 *                 case flow-mod-add-match-from-value-case {
 *                     container flow-mod-add-match-from-value {
 *                         leaf flow-mod-num-bits {
 *                             type uint16;
 *                         }
 *                         leaf value {
 *                             type uint16;
 *                         }
 *                         leaf src-field {
 *                             type uint32;
 *                         }
 *                         leaf src-ofs {
 *                             type uint16;
 *                         }
 *                     }
 *                 }
 *                 case flow-mod-copy-field-into-field-case {
 *                     container flow-mod-copy-field-into-field {
 *                         leaf flow-mod-num-bits {
 *                             type uint16;
 *                         }
 *                         leaf src-field {
 *                             type uint32;
 *                         }
 *                         leaf src-ofs {
 *                             type uint16;
 *                         }
 *                         leaf dst-field {
 *                             type uint32;
 *                         }
 *                         leaf dst-ofs {
 *                             type uint16;
 *                         }
 *                     }
 *                 }
 *                 case flow-mod-copy-value-into-field-case {
 *                     container flow-mod-copy-value-into-field {
 *                         leaf flow-mod-num-bits {
 *                             type uint16;
 *                         }
 *                         leaf value {
 *                             type uint16;
 *                         }
 *                         leaf dst-field {
 *                             type uint32;
 *                         }
 *                         leaf dst-ofs {
 *                             type uint16;
 *                         }
 *                     }
 *                 }
 *                 case flow-mod-output-to-port-case {
 *                     container flow-mod-output-to-port {
 *                         leaf flow-mod-num-bits {
 *                             type uint16;
 *                         }
 *                         leaf src-field {
 *                             type uint32;
 *                         }
 *                         leaf src-ofs {
 *                             type uint16;
 *                         }
 *                     }
 *                 }
 *             }
 *             uses flow-mod-spec;
 *         }
 *     }
 * }
 * </pre>
 * The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/update-flow/input/updated-flow/instructions/instruction/instruction/write-actions-case/write-actions/action/action/(urn:opendaylight:openflowplugin:extension:nicira:action?revision=2014-07-14)nx-action-learn-rpc-update-flow-updated-write-actions-case</i>
 *
 */
public interface NxActionLearnRpcUpdateFlowUpdatedWriteActionsCase
    extends
    DataObject,
    Augmentable<org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.update.flow.input.updated.flow.instructions.instruction.instruction.write.actions._case.write.actions.action.action.NxActionLearnRpcUpdateFlowUpdatedWriteActionsCase>,
    NxActionLearnGrouping,
    Action
{



    public static final QName QNAME = org.opendaylight.yangtools.yang.common.QName.create("urn:opendaylight:openflowplugin:extension:nicira:action",
        "2014-07-14", "nx-action-learn-rpc-update-flow-updated-write-actions-case").intern();


}
